@@ -12,8 +12,7 @@ use crate::{
 };
 use is_macro::Is;
 use serde::{Deserialize, Serialize};
-use swc_common::EqIgnoreSpan;
-use swc_common::{ast_node, Span};
+use swc_common::{ast_node, EqIgnoreSpan, Span};
 
 #[ast_node]
 #[derive(Eq, Hash, EqIgnoreSpan)]
